==> knative-model-6.3.1-sources.jar: io/fabric8/knative/flows/v1/SequenceStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface SequenceStatusFluent<A extends SequenceStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public SequenceStatusFluent.AddressNested<A> withNewAddress();
  public SequenceStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public SequenceStatusFluent.AddressNested<A> editAddress();
  public SequenceStatusFluent.AddressNested<A> editOrNewAddress();
  public SequenceStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToChannelStatuses(Integer index,SequenceChannelStatus item);
  public A setToChannelStatuses(Integer index,SequenceChannelStatus item);
  public A addToChannelStatuses(io.fabric8.knative.flows.v1.SequenceChannelStatus... items);
  public A addAllToChannelStatuses(Collection<SequenceChannelStatus> items);
  public A removeFromChannelStatuses(io.fabric8.knative.flows.v1.SequenceChannelStatus... items);
  public A removeAllFromChannelStatuses(Collection<SequenceChannelStatus> items);
  public A removeMatchingFromChannelStatuses(Predicate<SequenceChannelStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildChannelStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SequenceChannelStatus> getChannelStatuses();
  public List<SequenceChannelStatus> buildChannelStatuses();
  public SequenceChannelStatus buildChannelStatus(Integer index);
  public SequenceChannelStatus buildFirstChannelStatus();
  public SequenceChannelStatus buildLastChannelStatus();
  public SequenceChannelStatus buildMatchingChannelStatus(Predicate<SequenceChannelStatusBuilder> predicate);
  public Boolean hasMatchingChannelStatus(Predicate<SequenceChannelStatusBuilder> predicate);
  public A withChannelStatuses(List<SequenceChannelStatus> channelStatuses);
  public A withChannelStatuses(io.fabric8.knative.flows.v1.SequenceChannelStatus... channelStatuses);
  public Boolean hasChannelStatuses();
  public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatus();
  public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatusLike(SequenceChannelStatus item);
  public SequenceStatusFluent.ChannelStatusesNested<A> setNewChannelStatusLike(Integer index,SequenceChannelStatus item);
  public SequenceStatusFluent.ChannelStatusesNested<A> editChannelStatus(Integer index);
  public SequenceStatusFluent.ChannelStatusesNested<A> editFirstChannelStatus();
  public SequenceStatusFluent.ChannelStatusesNested<A> editLastChannelStatus();
  public SequenceStatusFluent.ChannelStatusesNested<A> editMatchingChannelStatus(Predicate<SequenceChannelStatusBuilder> predicate);
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public SequenceStatusFluent.ConditionsNested<A> addNewCondition();
  public SequenceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public SequenceStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public SequenceStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public SequenceStatusFluent.ConditionsNested<A> editFirstCondition();
  public SequenceStatusFluent.ConditionsNested<A> editLastCondition();
  public SequenceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public A addToSubscriptionStatuses(Integer index,SequenceSubscriptionStatus item);
  public A setToSubscriptionStatuses(Integer index,SequenceSubscriptionStatus item);
  public A addToSubscriptionStatuses(io.fabric8.knative.flows.v1.SequenceSubscriptionStatus... items);
  public A addAllToSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
  public A removeFromSubscriptionStatuses(io.fabric8.knative.flows.v1.SequenceSubscriptionStatus... items);
  public A removeAllFromSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
  public A removeMatchingFromSubscriptionStatuses(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscriptionStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SequenceSubscriptionStatus> getSubscriptionStatuses();
  public List<SequenceSubscriptionStatus> buildSubscriptionStatuses();
  public SequenceSubscriptionStatus buildSubscriptionStatus(Integer index);
  public SequenceSubscriptionStatus buildFirstSubscriptionStatus();
  public SequenceSubscriptionStatus buildLastSubscriptionStatus();
  public SequenceSubscriptionStatus buildMatchingSubscriptionStatus(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  public Boolean hasMatchingSubscriptionStatus(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  public A withSubscriptionStatuses(List<SequenceSubscriptionStatus> subscriptionStatuses);
  public A withSubscriptionStatuses(io.fabric8.knative.flows.v1.SequenceSubscriptionStatus... subscriptionStatuses);
  public Boolean hasSubscriptionStatuses();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatus();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatusLike(SequenceSubscriptionStatus item);
  public SequenceStatusFluent.SubscriptionStatusesNested<A> setNewSubscriptionStatusLike(Integer index,SequenceSubscriptionStatus item);
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editSubscriptionStatus(Integer index);
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editFirstSubscriptionStatus();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editLastSubscriptionStatus();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editMatchingSubscriptionStatus(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<SequenceStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ChannelStatusesNested<N> extends Nested<N>,SequenceChannelStatusFluent<SequenceStatusFluent.ChannelStatusesNested<N>>{
    public N and();
    public N endChannelStatus();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<SequenceStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface SubscriptionStatusesNested<N> extends Nested<N>,SequenceSubscriptionStatusFluent<SequenceStatusFluent.SubscriptionStatusesNested<N>>{
    public N and();
    public N endSubscriptionStatus();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/flows/v1/SequenceStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface SequenceStatusFluent<A extends SequenceStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public SequenceStatusFluent.AddressNested<A> withNewAddress();
  public SequenceStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public SequenceStatusFluent.AddressNested<A> editAddress();
  public SequenceStatusFluent.AddressNested<A> editOrNewAddress();
  public SequenceStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToChannelStatuses(int index,SequenceChannelStatus item);
  public A setToChannelStatuses(int index,SequenceChannelStatus item);
  public A addToChannelStatuses(io.fabric8.knative.flows.v1.SequenceChannelStatus... items);
  public A addAllToChannelStatuses(Collection<SequenceChannelStatus> items);
  public A removeFromChannelStatuses(io.fabric8.knative.flows.v1.SequenceChannelStatus... items);
  public A removeAllFromChannelStatuses(Collection<SequenceChannelStatus> items);
  public A removeMatchingFromChannelStatuses(Predicate<SequenceChannelStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildChannelStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SequenceChannelStatus> getChannelStatuses();
  public List<SequenceChannelStatus> buildChannelStatuses();
  public SequenceChannelStatus buildChannelStatus(int index);
  public SequenceChannelStatus buildFirstChannelStatus();
  public SequenceChannelStatus buildLastChannelStatus();
  public SequenceChannelStatus buildMatchingChannelStatus(Predicate<SequenceChannelStatusBuilder> predicate);
  public Boolean hasMatchingChannelStatus(Predicate<SequenceChannelStatusBuilder> predicate);
  public A withChannelStatuses(List<SequenceChannelStatus> channelStatuses);
  public A withChannelStatuses(io.fabric8.knative.flows.v1.SequenceChannelStatus... channelStatuses);
  public Boolean hasChannelStatuses();
  public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatus();
  public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatusLike(SequenceChannelStatus item);
  public SequenceStatusFluent.ChannelStatusesNested<A> setNewChannelStatusLike(int index,SequenceChannelStatus item);
  public SequenceStatusFluent.ChannelStatusesNested<A> editChannelStatus(int index);
  public SequenceStatusFluent.ChannelStatusesNested<A> editFirstChannelStatus();
  public SequenceStatusFluent.ChannelStatusesNested<A> editLastChannelStatus();
  public SequenceStatusFluent.ChannelStatusesNested<A> editMatchingChannelStatus(Predicate<SequenceChannelStatusBuilder> predicate);
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(int index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public SequenceStatusFluent.ConditionsNested<A> addNewCondition();
  public SequenceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public SequenceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
  public SequenceStatusFluent.ConditionsNested<A> editCondition(int index);
  public SequenceStatusFluent.ConditionsNested<A> editFirstCondition();
  public SequenceStatusFluent.ConditionsNested<A> editLastCondition();
  public SequenceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public A addToSubscriptionStatuses(int index,SequenceSubscriptionStatus item);
  public A setToSubscriptionStatuses(int index,SequenceSubscriptionStatus item);
  public A addToSubscriptionStatuses(io.fabric8.knative.flows.v1.SequenceSubscriptionStatus... items);
  public A addAllToSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
  public A removeFromSubscriptionStatuses(io.fabric8.knative.flows.v1.SequenceSubscriptionStatus... items);
  public A removeAllFromSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
  public A removeMatchingFromSubscriptionStatuses(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscriptionStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SequenceSubscriptionStatus> getSubscriptionStatuses();
  public List<SequenceSubscriptionStatus> buildSubscriptionStatuses();
  public SequenceSubscriptionStatus buildSubscriptionStatus(int index);
  public SequenceSubscriptionStatus buildFirstSubscriptionStatus();
  public SequenceSubscriptionStatus buildLastSubscriptionStatus();
  public SequenceSubscriptionStatus buildMatchingSubscriptionStatus(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  public Boolean hasMatchingSubscriptionStatus(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  public A withSubscriptionStatuses(List<SequenceSubscriptionStatus> subscriptionStatuses);
  public A withSubscriptionStatuses(io.fabric8.knative.flows.v1.SequenceSubscriptionStatus... subscriptionStatuses);
  public Boolean hasSubscriptionStatuses();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatus();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatusLike(SequenceSubscriptionStatus item);
  public SequenceStatusFluent.SubscriptionStatusesNested<A> setNewSubscriptionStatusLike(int index,SequenceSubscriptionStatus item);
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editSubscriptionStatus(int index);
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editFirstSubscriptionStatus();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editLastSubscriptionStatus();
  public SequenceStatusFluent.SubscriptionStatusesNested<A> editMatchingSubscriptionStatus(Predicate<SequenceSubscriptionStatusBuilder> predicate);
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<SequenceStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ChannelStatusesNested<N> extends Nested<N>,SequenceChannelStatusFluent<SequenceStatusFluent.ChannelStatusesNested<N>>{
    public N and();
    public N endChannelStatus();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<SequenceStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface SubscriptionStatusesNested<N> extends Nested<N>,SequenceSubscriptionStatusFluent<SequenceStatusFluent.SubscriptionStatusesNested<N>>{
    public N and();
    public N endSubscriptionStatus();
    
  }
  
}
